@@ -3,15 +3,15 @@ from ...scanner_utils import is_quote, is_space, is_number, is_alpha, is_alpha_n
 from .utils import Chars, escaped
 from . import tokens
 
-OPERATOR_TYPES = dict([
-    (Chars.Child, 'child'),
-    (Chars.Sibling, 'sibling'),
-    (Chars.Climb, 'climb'),
-    (Chars.Dot, 'class'),
-    (Chars.Hash, 'id'),
-    (Chars.Slash, 'close'),
-    (Chars.Equals, 'equal')
-])
+OPERATOR_TYPES = {
+    Chars.Child: 'child',
+    Chars.Sibling: 'sibling',
+    Chars.Climb: 'climb',
+    Chars.Dot: 'class',
+    Chars.Hash: 'id',
+    Chars.Slash: 'close',
+    Chars.Equals: 'equal'
+}
 
 
 def tokenize(source: str):
@@ -106,7 +106,7 @@ def white_space(scanner: Scanner):
     "Consumes white space characters as string literal from given scanner"
     start = scanner.pos
     if scanner.eat_while(is_space):
-        return tokens.WhiteSpace(start, scanner.pos)
+        return tokens.WhiteSpace(scanner.substring(start, scanner.pos), start, scanner.pos)
 
 
 def quote(scanner: Scanner):
