@@ -1,5 +1,5 @@
 snippets = {
-	"@f": "@font-face {\n\tfont-family: ${1};\n\tsrc: url(${1});\n}",
+	"@f": "@font-face {\n\tfont-family: ${1};\n\tsrc: url(${2});\n}",
 	"@ff": "@font-face {\n\tfont-family: '${1:FontName}';\n\tsrc: url('${2:FileName}.eot');\n\tsrc: url('${2:FileName}.eot?#iefix') format('embedded-opentype'),\n\t\t url('${2:FileName}.woff') format('woff'),\n\t\t url('${2:FileName}.ttf') format('truetype'),\n\t\t url('${2:FileName}.svg#${1:FontName}') format('svg');\n\tfont-style: ${3:normal};\n\tfont-weight: ${4:normal};\n}",
 	"@i|@import": "@import url(${0});",
 	"@kf": "@keyframes ${1:identifier} {\n\t${2}\n}",
@@ -92,7 +92,7 @@ snippets = {
 	"cp": "clip:auto|rect(${1:top} ${2:right} ${3:bottom} ${4:left})",
 	"cps": "caption-side:top|bottom",
 	"cur": "cursor:pointer|auto|default|crosshair|hand|help|move|pointer|text",
-	"d": "display:block|none|flex|inline-flex|inline|inline-block|grid|inline-grid|subgrid|list-item|run-in|compact|table|inline-table|table-caption|table-column|table-column-group|table-header-group|table-footer-group|table-row|table-row-group|table-cell|ruby|ruby-base|ruby-base-group|ruby-text|ruby-text-group",
+	"d": "display:block|none|flex|inline-flex|inline|inline-block|grid|inline-grid|subgrid|list-item|run-in|contents|table|inline-table|table-caption|table-column|table-column-group|table-header-group|table-footer-group|table-row|table-row-group|table-cell|ruby|ruby-base|ruby-base-group|ruby-text|ruby-text-group",
 	"ec": "empty-cells:show|hide",
 	"f": "font:${1:1em} ${2:sans-serif}",
 	"fd": "font-display:auto|block|swap|fallback|optional",
@@ -120,8 +120,9 @@ snippets = {
 	"fxw": "flex-wrap:nowrap|wrap|wrap-reverse",
 	"fsz": "font-size",
 	"fsza": "font-size-adjust",
-	"gtc": "grid-template-columns:repeat()|minmax()",
-	"gtr": "grid-template-rows:repeat()|minmax()",
+    "g": "gap",
+	"gtc": "grid-template-columns:repeat(${0})|minmax()",
+	"gtr": "grid-template-rows:repeat(${0})|minmax()",
 	"gta": "grid-template-areas",
 	"gt": "grid-template",
 	"gg": "grid-gap",
@@ -166,7 +167,7 @@ snippets = {
 	"olo": "outline-offset",
 	"ols": "outline-style:none|dotted|dashed|solid|double|groove|ridge|inset|outset",
 	"olw": "outline-width|thin|medium|thick",
-	"op": "opacity",
+	"op|opa": "opacity",
 	"ord": "order",
 	"ori": "orientation:landscape|portrait",
 	"orp": "orphans",
